@@ -17,8 +17,9 @@ function squirrelmail_plugin_init_image_buttons() {
 
     $squirrelmail_plugin_hooks['internal_link']['image_buttons'] = 'image_buttons_register_block';
     if ($GLOBALS['image_buttons_select'] == 1) {
-        $squirrelmail_plugin_hooks['optpage_loadhook_display']['image_buttons'] = 'image_buttons_loadhook_display';
-        $squirrelmail_plugin_hooks['loading_prefs']['image_buttons']  = 'image_buttons_loading_prefs';
+        $squirrelmail_plugin_hooks['options_display_inside']['image_buttons'] = 'image_buttons_display_inside';
+        $squirrelmail_plugin_hooks['options_display_save']['image_buttons']   = 'image_buttons_display_save';
+        $squirrelmail_plugin_hooks['options_loading_prefs']['image_buttons']  = 'image_buttons_loading_prefs';
     }
 }
 
@@ -31,12 +32,22 @@ function image_buttons_register_block($args) {
     return image_buttons_do($args);
 }
 
-function image_buttons_loadhook_display() {
+function image_buttons_display_inside() {
+
     if (defined('SM_PATH'))
         include_once(SM_PATH . 'plugins/image_buttons/functions.php');
     else
         include_once('../plugins/image_buttons/functions.php');
-    image_buttons_loadhook_display_do();
+    image_buttons_display();
+}
+
+function image_buttons_display_save() {
+
+    if (defined('SM_PATH'))
+        include_once(SM_PATH . 'plugins/image_buttons/functions.php');
+    else
+        include_once('../plugins/image_buttons/functions.php');
+    image_buttons_save();
 }
 
 function image_buttons_loading_prefs() {
@@ -49,6 +60,6 @@ function image_buttons_loading_prefs() {
 }
 
 function image_buttons_version() {
-    return '1.4';
+    return '1.31';
 }
 ?>
